@@ -1,6 +1,6 @@
 /* -*- Mode: C -*-
 
-  $Id: gpgmeplug.c,v 1.2.2.2 2002/12/05 08:36:38 werner Exp $
+  $Id: gpgmeplug.c,v 1.2.2.5 2003/05/04 17:42:36 marcus Exp $
 
   GPGMEPLUG - an GPGME based cryptography plug-in following
               the common CRYPTPLUG specification.
@@ -269,7 +269,7 @@ bool initialize()
   config.saveMessagesEncrypted                = true;
   config.checkEncryptionCertificatePathToRoot = true;
   config.encryptionUseCRLs                    = true;
-  config.encryptionCRLExpiryNearWarning       = true;
+  config.encryptionCRLExpiryNearWarning       = false;
   config.encryptionCRLNearExpiryInterval      = NEAR_EXPIRY;
   config.directoryServers                     = NULL;
   config.numDirectoryServers                  = 0;
@@ -942,12 +942,41 @@ bool certificateInChainExpiryNearWarning()
 
 int certificateInChainDaysLeftToExpiry( const char* certificate )
 {
-    /* PENDING(g10)
-       Please return the number of days that are left until the
-       the first certificate in the chain of the specified certificate
-       expires.
-    */
-  return 10; /* dummy that triggers a warning in the MUA */
+  GpgmeCtx ctx;
+  GpgmeError err;
+  int daysLeft = CRYPTPLUG_CERT_DOES_NEVER_EXPIRE;
+
+  gpgme_new (&ctx);
+  gpgme_set_protocol (ctx, GPGMEPLUG_PROTOCOL);
+
+  do
+    {      
+      GpgmeKey rKey;
+      int days;
+
+      err = gpgme_op_keylist_start (ctx, certificate, 0);
+      if (!err)
+	err = gpgme_op_keylist_next (ctx, &rKey);
+      if (!err)
+	err = gpgme_op_keylist_end (ctx);
+      if (err)
+	break;
+      
+      certificate = gpgme_key_get_string_attr (rKey, GPGME_ATTR_CHAINID, NULL, 0);
+      days = getAttrExpireFormKey (&rKey);
+      if (days < daysLeft)
+        daysLeft = days;
+
+      gpgme_key_release (rKey);
+    }
+  while (certificate);
+
+  if (err)
+    fprintf (stderr, "Error listing certificate chain: %s\n",
+	     gpgme_strerror (err));
+
+  gpgme_release (ctx);
+  return daysLeft;
 }
 
 
@@ -996,11 +1025,7 @@ bool encryptionUseCRLs()
 
 int encryptionCRLsDaysLeftToExpiry()
 {
-    /* PENDING(g10)
-       Please return the number of days that are left until the
-       CRL used for encryption expires.
-    */
-  return 10; /* dummy that triggers a warning in the MUA */
+  return CRYPTPLUG_CERT_DOES_NEVER_EXPIRE;
 }
 
 void setEncryptionCRLExpiryNearWarning( bool flag )
@@ -1733,7 +1758,7 @@ bool decryptMessage( const char* ciphertext,
 
   gpgme_data_new( &gPlaintext );
 
-  err = err = gpgme_op_decrypt( ctx, gCiphertext, gPlaintext );
+  err = gpgme_op_decrypt( ctx, gCiphertext, gPlaintext );
   if( err ) {
     fprintf( stderr, "\ngpgme_op_decrypt() returned this error code:  %i\n\n", err );
     if( errId )
