@@ -1,6 +1,6 @@
 /* -*- Mode: C -*-
 
-  $Id: cryptplug.h,v 1.24 2002/11/27 12:33:53 marcus Exp $
+  $Id: cryptplug.h,v 1.24.2.1 2002/12/05 09:08:34 werner Exp $
 
   CRYPTPLUG - an independent cryptography plug-in API
 
@@ -328,6 +328,24 @@ const char* libVersion( void );
 */
 const char* bugURL( void );
 
+
+/*! \ingroup groupGeneral
+    \brief Return the current interface version of the plugin.
+
+   Return the current interface version.  This is a simple way for a
+   user to check whether all required fucntions are available.  If
+   MIN_VERSION is not NULL the lowest supported version of the
+   interface is returned in addition.
+
+   The version is a positive integer.  A user should check for the
+   existance of this function before using it; if the fucntion does
+   not exist, a interface version of 0 should be assumed.
+
+   This function may be called prior to initialize().
+  */
+int interfaceVersion (int *min_version); 
+
+
 /*! \ingroup groupGeneral
     \brief This function sets up all internal structures.
 
